MODULE bdy_oce
   !!======================================================================
   !!                       ***  MODULE bdy_oce   ***
   !! Unstructured Open Boundary Cond. :   define related variables
   !!======================================================================
#if defined key_bdy || defined key_bdy_tides
   !!----------------------------------------------------------------------
   !!   'key_bdy' :                    Unstructured Open Boundary Condition
   !!----------------------------------------------------------------------
   !! History :
   !!  9.0   01/05   (J. Chanut, A. Sellar)  Original code
   !!----------------------------------------------------------------------
   !! * Modules used
   USE par_oce         ! ocean parameters
   USE bdy_par         ! Unstructured boundary parameters

   IMPLICIT NONE
   PUBLIC

   !!----------------------------------------------------------------------
   !! Namelist variables
   !!----------------------------------------------------------------------

   CHARACTER(len=80) :: &
      filbdy_mask, &         !: Name of unstruct. bdy mask file
      filbdy_data_T, &       !: Name of unstruct. bdy data file at T points
      filbdy_data_U, &       !: Name of unstruct. bdy data file at U points
      filbdy_data_V, &       !: Name of unstruct. bdy data file at V points
      filbdy_data_bt_T, &    !: Name of unstruct. bdy data file at T points for barotropic variables
      filbdy_data_bt_U, &    !: Name of unstruct. bdy data file at U points for barotropic variables
      filbdy_data_bt_V       !: Name of unstruct. bdy data file at V points for barotropic variables

   LOGICAL ::  &
      ln_bdy_clim =.false.!: if true, we assume that bdy data files contain 
                          !  1 time dump (-->bdy forcing will be constant) 
                          !  or 12 months  (-->bdy forcing will be cyclic) 
   LOGICAL ::  &
      ln_bdy_fla =.false. !: if true, flather boundary conditions

   LOGICAL ::  &
      ln_bdy_vol =.false. !: if true, volume correction             

   LOGICAL ::  &
      ln_bdy_mask = .false. !: if true, read bdymask from file

   INTEGER ::  &
      nb_rimwidth = 7,	& !: boundary rim width
      nbdy_dta = 1	  !: = 0 use the initial state as bdy dta
                          !: = 1 read bdy data in netcdf file
   INTEGER ::  & 
      volbdy = 1          !: = 0 the total volume will have the variability 
                          !       of the surface Flux E-P else (volbdy = 1) 
                          !       the volume will be constant
                          !  = 1 the volume will be constant during all the 
                          !       integration.

   !!----------------------------------------------------------------------
   !! Global variables
   !!----------------------------------------------------------------------

   REAL(wp), DIMENSION(jpi, jpj) ::  & !:
      bdytmask, &  !: Mask defining computational domain at T-points
      bdyumask, &  !: Mask defining computational domain at U-points
      bdyvmask     !: Mask defining computational domain at V-points

   !!----------------------------------------------------------------------
   !! Unstructured open boundary data variables
   !!----------------------------------------------------------------------

   INTEGER, DIMENSION(jpbgrd) ::  &
      nblen  = 0,	& !: Size of bdy data on a proc for each grid type
      nblenrim = 0,	& !: Size of bdy data on a proc for first rim ind
      nblendta = 0        !: Size of bdy data in file

   INTEGER, DIMENSION(jpbdim, jpbgrd) ::  & 
      nbi, nbj,		& !: i and j indices of bdy dta
      nbr,		& !: Discrete distance from rim points
      nbmap		  !: Indices of data in file for data in memory 
    
   REAL(wp) :: &
      bdysurftot	  !: Lateral surface of unstructured open boundary

   REAL(wp), DIMENSION(jpbdim) ::  &
      flagu,		& !: Flag for normal velocity compnt for u-velocity
      flagv		  !: Flag for normal velocity compnt for v-velocity

   REAL(wp), DIMENSION(jpbdim, jpbgrd) ::  &
      nbw		  !: Rim weights of bdy data

   REAL(wp), DIMENSION(jpbdim) ::  &
      sshbdy,		& !: Now clim of bdy sea surface height (Flather)
      ubtbdy, vbtbdy	  !: Now clim of bdy barotropic velocity components

   REAL(wp), DIMENSION(jpbdim,jpk) ::  &
      tbdy, sbdy,	& !: Now clim of bdy temperature and salinity  
      ubdy, vbdy	  !: Now clim of bdy velocity components

#if defined key_bdy_tides
   REAL(wp), DIMENSION(jpbdim) ::  &
      sshtide,          & !: Tidal boundary array : SSH
      utide,            & !: Tidal boundary array : U
      vtide	          !: Tidal boundary array : V
#endif
		    
#else
   !!----------------------------------------------------------------------
   !!   Default option :                                       Empty module
   !!----------------------------------------------------------------------
#endif

   !!======================================================================
END MODULE bdy_oce
